@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -55,7 +55,10 @@ switch (get_request_var('action')) {
 		get_filter_request_var('span');
 		get_filter_request_var('rows');
 
-		$sampling_interval = db_fetch_cell_prepared('SELECT step FROM data_source_profiles WHERE id = ?', array(get_request_var('profile_id')));
+		$sampling_interval = db_fetch_cell_prepared('SELECT step
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('profile_id')));
 
 		if (get_request_var('span') == 1) {
 			print get_span(get_request_var('rows') * $sampling_interval);
@@ -171,16 +174,27 @@ function form_save() {
 		get_filter_request_var('profile_id');
 		/* ==================================================== */
 
-		$sampling_interval = db_fetch_cell_prepared('SELECT step FROM data_source_profiles WHERE id = ?', array(get_request_var('profile_id')));
+		$sampling_interval = db_fetch_cell_prepared('SELECT step
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('profile_id')));
+
 		$save['id']                      = form_input_validate(get_request_var('id'), 'id', '^[0-9]+$', false, 3);
 		$save['name']                    = form_input_validate(get_nfilter_request_var('name'), 'name', '', true, 3);
 		$save['data_source_profile_id']  = form_input_validate(get_request_var('profile_id'), 'profile_id', '^[0-9]+$', false, 3);
-		$save['steps']                   = form_input_validate(get_nfilter_request_var('steps'), 'steps', '^[0-9]+$', false, 3);
+		$save['timespan']                = form_input_validate(get_nfilter_request_var('timespan'), 'timespan', '^[0-9]+$', false, 3);
 
-		if ($save['steps'] != '1') {
-			$save['steps'] /= $sampling_interval;
+		if (isset_request_var('steps')) {
+			$save['steps'] = form_input_validate(get_nfilter_request_var('steps'), 'steps', '^[0-9]+$', false, 3);
+
+			if ($save['steps'] != '1') {
+				$save['steps'] /= $sampling_interval;
+			}
+		}
+
+		if (isset_request_var('rows')) {
+			$save['rows'] = form_input_validate(get_nfilter_request_var('rows'), 'rows', '^[0-9]+$', false, 3);
 		}
-		$save['rows']                    = form_input_validate(get_nfilter_request_var('rows'), 'rows', '^[0-9]+$', false, 3);
 
 		if (!is_error_message()) {
 			$profile_rra_id = sql_save($save, 'data_source_profiles_rra');
@@ -241,7 +255,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$profile_list .= '<li>' . htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM data_source_profiles WHERE id = ?', array($matches[1]))) . '</li>';
+			$profile_list .= '<li>' . html_escape(db_fetch_cell_prepared('SELECT name FROM data_source_profiles WHERE id = ?', array($matches[1]))) . '</li>';
 			$profile_array[$i] = $matches[1];
 
 			$i++;
@@ -310,7 +324,10 @@ function profile_item_remove_confirm() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$profile = db_fetch_row_prepared('SELECT * FROM data_source_profiles_rra WHERE id = ?', array(get_request_var('id')));
+	$profile = db_fetch_row_prepared('SELECT *
+		FROM data_source_profiles_rra
+		WHERE id = ?',
+		array(get_request_var('id')));
 
 	?>
 	<tr>
@@ -334,8 +351,6 @@ function profile_item_remove_confirm() {
 	?>
 	<script type='text/javascript'>
 	$(function() {
-		$('#cdialog').dialog();
-
 		$('#continue').click(function(data) {
 			$.post('data_source_profiles.php?action=item_remove', {
 				__csrf_magic: csrfMagicToken,
@@ -372,6 +387,12 @@ function item_edit() {
 		WHERE id = ?',
 		array(get_request_var('profile_id')));
 
+	$readonly = db_fetch_cell_prepared('SELECT COUNT(*)
+		FROM data_template_data AS dtd
+		WHERE data_source_profile_id = ?
+		AND local_data_id > 0',
+		array(get_request_var('profile_id')));
+
 	if (!isempty_request_var('id')) {
 		$rra = db_fetch_row_prepared('SELECT *
 			FROM data_source_profiles_rra
@@ -405,13 +426,19 @@ function item_edit() {
 					unset($aggregation_levels[$interval]);
 				}
 			}
+
 			$fields_profile_rra_edit['steps']['array'] = $aggregation_levels;
 		}
 	}
 
 	form_start('data_source_profiles.php', 'form_rra');
 
-	html_start_box( __('RRA [edit: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM data_source_profiles_rra WHERE id = ?', array(get_request_var('id')))) ), '100%', true, '3', 'center', '');
+	$name = db_fetch_cell_prepared('SELECT name
+		FROM data_source_profiles_rra
+		WHERE id = ?',
+		array(get_request_var('id')));
+
+	html_start_box( __('RRA [edit: %s %s]', $name, ($readonly ? __('(Some Elements Read Only)'):'')), '100%', true, '3', 'center', '');
 
 	draw_edit_form(array(
 		'config' => array('no_form_tag' => true),
@@ -430,6 +457,7 @@ function item_edit() {
 
 	var profile_id=<?php print get_request_var('profile_id') != '' ? get_request_var('profile_id'):0;?>;
 	var rows_to = false;
+	var readonly = <?php print ($readonly ? 'true':'false');?>;
 
 	$(function() {
 		get_span();
@@ -444,18 +472,32 @@ function item_edit() {
             if (rows_to) { clearTimeout(rows_to); }
             rows_to = setTimeout(function () { get_span(); get_size() }, 250);
         });
+
+		if (readonly) {
+			$('#steps').prop('disabled', true);
+			$('#rows').prop('disabled', true);
+		}
 	});
 
 	function get_size() {
-		$.get('data_source_profiles.php?action=ajax_size&type=rra&id='+profile_id+'&rows='+$('#rows').val(), function(data) {
-			$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_size&type=rra&id='+profile_id+'&rows='+$('#rows').val())
+			.done(function(data) {
+				$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
 	}
 
 	function get_span() {
-		$.get('data_source_profiles.php?action=ajax_span&profile_id='+profile_id+'&span='+$('#steps').val()+'&rows='+$('#rows').val(), function(data) {
-			$('#row_timespan').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_span&profile_id='+profile_id+'&span='+$('#steps').val()+'&rows='+$('#rows').val())
+			.done(function(data) {
+				$('#row_retention').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
+
 	}
 	</script>
 	<?php
@@ -466,19 +508,25 @@ function item_edit() {
    --------------------- */
 
 function profile_edit() {
-	global $fields_profile_edit;
+	global $fields_profile_edit, $timespans;
 
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
 	/* ==================================================== */
 
 	if (!isempty_request_var('id')) {
-		$profile = db_fetch_row_prepared('SELECT * FROM data_source_profiles WHERE id = ?', array(get_request_var('id')));
+		$profile = db_fetch_row_prepared('SELECT *
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('id')));
+
 		$readonly     = db_fetch_cell_prepared('SELECT COUNT(*)
 			FROM data_template_data AS dtd
-			WHERE data_source_profile_id = ? AND local_data_id > 0', array(get_request_var('id')));
+			WHERE data_source_profile_id = ?
+			AND local_data_id > 0',
+			array(get_request_var('id')));
 
-		$header_label = __('Data Source Profile [edit: %s]', htmlspecialchars($profile['name']) . ($readonly ? ' (Read Only)':''));
+		$header_label = __('Data Source Profile [edit: %s]', html_escape($profile['name']) . ($readonly ? ' (Read Only)':''));
 	} else {
 		$header_label = __('Data Source Profile [new]');
 		$readonly     = false;
@@ -504,30 +552,38 @@ function profile_edit() {
 		}
 
 		$display_text = array(
-			array('display' => __('Name'),               'align' => 'left'),
-			array('display' => __('Effective Timespan'), 'align' => 'left'),
-			array('display' => __('Steps'),              'align' => 'left'),
-			array('display' => __('Rows'),               'align' => 'left'),
+			array('display' => __('Name'),           'align' => 'left'),
+			array('display' => __('Data Retention'), 'align' => 'left'),
+			array('display' => __('Graph Timespan'), 'align' => 'left'),
+			array('display' => __('Steps'),          'align' => 'left'),
+			array('display' => __('Rows'),           'align' => 'left'),
 		);
 
 		html_header($display_text, 2);
 
-		$profile_rras = db_fetch_assoc_prepared('SELECT * FROM data_source_profiles_rra WHERE data_source_profile_id = ? ORDER BY steps', array(get_request_var('id')));
+		$profile_rras = db_fetch_assoc_prepared('SELECT *
+			FROM data_source_profiles_rra
+			WHERE data_source_profile_id = ?
+			ORDER BY steps',
+			array(get_request_var('id')));
 
 		$i = 0;
 		if (sizeof($profile_rras)) {
 			foreach ($profile_rras as $rra) {
 				form_alternate_row('line' . $rra['id']);$i++;?>
 				<td>
-					<?php print (!$readonly ? "<a class='linkEditMain' href='" . htmlspecialchars('data_source_profiles.php?action=item_edit&id=' . $rra['id'] . '&profile_id=' . $rra['data_source_profile_id']) . "'>":"") . htmlspecialchars($rra['name']) . (!$readonly ? "</a>":"");?>
+					<?php print "<a class='linkEditMain' href='" . html_escape('data_source_profiles.php?action=item_edit&id=' . $rra['id'] . '&profile_id=' . $rra['data_source_profile_id']) . "'>" . html_escape($rra['name']) . '</a>';?>
 				</td>
-				<td style='text-align:left'>
+				<td>
 					<em><?php print get_span($profile['step'] * $rra['steps'] * $rra['rows']);?></em>
 				</td>
-				<td style='text-align:left'>
+				<td>
+					<em><?php print isset($timespans[$rra['timespan']]) ? $timespans[$rra['timespan']]:get_span($rra['timespan']);?></em>
+				</td>
+				<td>
 					<em><?php print $rra['steps'];?></em>
 				</td>
-				<td style='text-align:left'>
+				<td>
 					<em><?php print $rra['rows'];?></em>
 				</td>
 				<td class='right'>
@@ -575,15 +631,19 @@ function profile_edit() {
 
 			id = $(this).attr('id').split('_');
 			request = 'data_source_profiles.php?action=item_remove_confirm&id='+id[1]+'&profle_id='+id[0];
-			$.get(request, function(data) {
-				$('#cdialog').html(data);
-				applySkin();
-				$('#cdialog').dialog({
-					title: '<?php print __('Delete Data Source Profile Item');?>',
-					close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
-					minHeight: 80,
-					minWidth: 500
-				});
+			$.get(request)
+				.done(function(data) {
+					$('#cdialog').html(data);
+					applySkin();
+					$('#cdialog').dialog({
+						title: '<?php print __('Delete Data Source Profile Item');?>',
+						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
+						minHeight: 80,
+						minWidth: 500
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
+					});
 			});
 		}).css('cursor', 'pointer');
 		<?php } else { ?>
@@ -597,9 +657,13 @@ function profile_edit() {
 
 	function get_size() {
 		checked = $('#consolidation_function_id').multiselect('getChecked').length;
-		$.get('data_source_profiles.php?action=ajax_size&type=profile&id='+profile_id+'&cfs='+checked, function(data) {
-			$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
-		});
+		$.get('data_source_profiles.php?action=ajax_size&type=profile&id='+profile_id+'&cfs='+checked)
+			.done(function(data) {
+				$('#row_size').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			})
+			.fail(function(data) {
+				getPresentHTTPError(data);
+			});
 	}
 
 	</script>
@@ -615,17 +679,27 @@ function get_size($id, $type, $cfs = '') {
 
 	if ($type == 'profile') {
 		if (empty($cfs)) {
-			$cfs  = db_fetch_cell_prepared('SELECT COUNT(*) FROM data_source_profiles_cf WHERE data_source_profile_id = ?', array($id));
+			$cfs  = db_fetch_cell_prepared('SELECT COUNT(*)
+				FROM data_source_profiles_cf
+				WHERE data_source_profile_id = ?',
+				array($id));
 		}
 
-		$rows = db_fetch_cell_prepared('SELECT SUM(`rows`) FROM data_source_profiles_rra WHERE data_source_profile_id = ?', array($id));
+		$rows = db_fetch_cell_prepared('SELECT SUM(`rows`)
+			FROM data_source_profiles_rra
+			WHERE data_source_profile_id = ?',
+			array($id));
 
-		return number_format_i18n(($rows * $row * $cfs + $dsheader) / 1000) . " KBytes per Data Source, and $header Bytes for the Header.";
+		return __('%s KBytes per Data Sources and %s Bytes for the Header', number_format_i18n(($rows * $row * $cfs + $dsheader) / 1000), $header);
 	} else {
-		$cfs  = db_fetch_cell_prepared('SELECT COUNT(*) FROM data_source_profiles_cf WHERE data_source_profile_id = ?', array($id));
+		$cfs  = db_fetch_cell_prepared('SELECT COUNT(*)
+			FROM data_source_profiles_cf
+			WHERE data_source_profile_id = ?',
+			array($id));
+
 		$rows = get_filter_request_var('rows');
 
-		return number_format_i18n(($rows * $row * $cfs) / 1000) . " KBytes per Data Source.";
+		return __('%s KBytes per Data Source', number_format_i18n(($rows * $row * $cfs) / 1000));
 	}
 }
 
@@ -751,7 +825,7 @@ function profile() {
 							<?php
 							if (sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -895,7 +969,7 @@ function profile() {
 
 			form_alternate_row('line' . $profile['id'], false, $disabled);
 			form_selectable_cell(filter_value($profile['name'], get_request_var('filter'), 'data_source_profiles.php?action=edit&id=' . $profile['id']), $profile['id']);
-			form_selectable_cell($profile['default'] == 'on' ? 'Yes':'', $profile['id'], '', 'text-align:right');
+			form_selectable_cell($profile['default'] == 'on' ? __('Yes'):'', $profile['id'], '', 'text-align:right');
 			form_selectable_cell($disabled ? __('No') : __('Yes'), $profile['id'], '', 'text-align:right');
 			form_selectable_cell($readonly ? __('Yes') : __('No'), $profile['id'], '', 'text-align:right');
 			form_selectable_cell($sampling_intervals[$profile['step']], $profile['id'], '', 'text-align:right');
@@ -906,8 +980,9 @@ function profile() {
 			form_end_row();
 		}
 	} else {
-		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Data Source Profiles') . "</em></td></tr>\n";
+		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Data Source Profiles Found') . "</em></td></tr>\n";
 	}
+
 	html_end_box(false);
 
 	if (sizeof($profile_list)) {
