@@ -552,7 +552,7 @@ function cactiReturnTo(href) {
 function applySkin() {
 	pageName = basename($(location).attr('pathname'));
 
-	if (typeof requestURI !== 'undefined') {
+	if (typeof requestURI != 'undefined') {
 		pushState(myTitle, requestURI);
 	}
 
@@ -973,7 +973,12 @@ function responsiveResizeGraphs() {
 	myWidth = parseInt((graphRow - (drillDown * myColumns)) / myColumns);
 
 	$('.graphimage').each(function() {
-		graph_id = $(this).attr('id').replace('wrapper_','');
+		graph_id = $(this).attr('graph_id');
+		if (!(graph_id > 0)) {
+			graph_id = $(this).attr('id').replace('wrapper_','');
+		}
+
+		rra_id = $(this).attr('rra_id');
 
 		/* original image attributes */
 		image_width   = $(this).attr('image_width');
@@ -1194,7 +1199,7 @@ function loadPage(href) {
 	statePushed = false;
 
 	$.get(href)
-		.success(function(html) {
+		.done(function(html) {
 			var htmlObject  = $(html);
 			var matches     = html.match(/<title>(.*?)<\/title>/);
 
@@ -1247,8 +1252,8 @@ function loadPage(href) {
 
 			return false;
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 
@@ -1259,7 +1264,7 @@ function loadPageNoHeader(href, scroll) {
 	statePushed = false;
 
 	$.get(href)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#main').empty().hide();
@@ -1286,8 +1291,8 @@ function loadPageNoHeader(href, scroll) {
 
 			return false;
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 
@@ -1295,47 +1300,51 @@ function loadPageNoHeader(href, scroll) {
 }
 
 function getPresentHTTPError(data) {
-	var title_match = data.match(/<title>(.*?)<\/title>/);
-	var head_match  = data.match(/<h1>(.*?)<\/h1>/);
-	var para_match  = data.match(/<p>(.*?)<\/p>/);
+	if (typeof data != 'undefined') {
+		errorStr  = data.status;
+		errorSub  = data.statusText;
+		errorText = errorReasonUnexpected;
 
-	errorStr  = '';
-	errorSub  = '';
-	errorText = '';
+		var dataText = data.responseText;
 
-	if (title_match != null) {
-		var errorStr = title_match[1];
-	}
+		var title_match = dataText.match(/<title>(.*?)<\/title>/);
+		var head_match  = dataText.match(/<h1>(.*?)<\/h1>/);
+		var para_match  = dataText.match(/<p>(.*?)<\/p>/);
 
-	if (head_match != null) {
-		var errorSub = head_match[1];
-	}
-
-	if (para_match != null) {
-		var errorText = para_match[1];
-	}
-
-	returnStr = '<div id="httperror" style="display:none">' +
-		'<h4>' + errorOnPage + '</h4><hr>' +
-		'<div style="padding-bottom: 5px;"><div style="display:table-cell;width:75px"><b>' + errorNumberPrefix + '</b></div> ' +
-		'<div style="display:table-cell"> ' + errorStr + '</div></div>' +
-		'<div><div style="display:table-cell;width:75px"><b>'  + errorReasonPrefix + '</b></div> ' +
-		'<div style="display:table-cell"> ' + errorText + '</div></div>' +
-		'</div></div>';
-
-	$('#httperror').remove();
-	$('body').append(returnStr);
-	$('#httperror').dialog({
-		resizable: false,
-		height: 'auto',
-		width: 400,
-		title: errorStr,
-		buttons: {
-			Ok: function() {
-				$(this).dialog('close');
-			}
+		if (title_match != null) {
+			var errorSub = title_match[1];
 		}
-	});
+
+		if (head_match != null) {
+			var errorSub = head_match[1];
+		}
+
+		if (para_match != null) {
+			var errorText = para_match[1];
+		}
+
+		returnStr = '<div id="httperror" style="display:none">' +
+			'<h4>' + errorOnPage + '</h4><hr>' +
+			'<div style="padding-bottom: 5px;"><div style="display:table-cell;width:75px"><b>' + errorNumberPrefix + '</b></div> ' +
+			'<div style="display:table-cell"> ' + errorStr + ' ' + errorSub + '</div></div>' +
+			'<div><div style="display:table-cell;width:75px"><b>'  + errorReasonPrefix + '</b></div> ' +
+			'<div style="display:table-cell"> ' + errorText + '</div></div>' +
+			'</div></div>';
+
+		$('#httperror').remove();
+		$('body').append(returnStr);
+		$('#httperror').dialog({
+			resizable: false,
+			height: 'auto',
+			width: 400,
+			title: errorReasonTitle,
+			buttons: {
+				Ok: function() {
+					$(this).dialog('close');
+				}
+			}
+		});
+	}
 }
 
 function ajaxAnchors() {
@@ -1485,7 +1494,7 @@ function setupSortable() {
 				sortAdd;
 
 			$.get(url)
-				.success(function(data) {
+				.done(function(data) {
 					checkForLogout(data);
 
 					$('#main').empty().hide();
@@ -1493,8 +1502,8 @@ function setupSortable() {
 					$('#main').html(data);
 					applySkin();
 				})
-				.error(function(data) {
-				getPresentHTTPError(data.responseText);
+				.fail(function(data) {
+					getPresentHTTPError(data);
 				}
 			);
 		}
@@ -1645,7 +1654,7 @@ function setupPageTimeout() {
 				refreshPage = refreshPage.replace('action=tree&', 'action=tree_content&');
 
 				$.get(refreshPage)
-					.success(function(data) {
+					.done(function(data) {
 						checkForLogout(data);
 
 						$('#main').empty().hide();
@@ -1653,8 +1662,8 @@ function setupPageTimeout() {
 						$('#main').html(data);
 						applySkin();
 					})
-					.error(function(data) {
-						getPresentHTTPError(data.responseText);
+					.fail(function(data) {
+						getPresentHTTPError(data);
 					}
 				);
 			}
@@ -1786,7 +1795,7 @@ var graphPage  = urlPath+'graph_view.php';
 var pageAction = 'preview';
 
 function checkForLogout(data) {
-	if (typeof data === 'undefined') {
+	if (typeof data == 'undefined') {
 		return true;
 	} else if (typeof data === 'object') {
 		return true;
@@ -1802,7 +1811,7 @@ function clearGraphFilter() {
 
 	$.ajaxQ.abortAll();
 	$.get(new_href+'&header=false')
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#main').empty().hide();
@@ -1810,8 +1819,8 @@ function clearGraphFilter() {
 			$('#main').html(data);
 			applySkin();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -1826,15 +1835,15 @@ function saveGraphFilter(section) {
 		'&thumbnails='+$('#thumbnails').is(':checked');
 
 	$.get(href+'&header=false&section='+section)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#text').show().text(filterSettingsSaved).fadeOut(2000, function() {
 				$('#text').empty();
 			});
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -1852,7 +1861,7 @@ function applyGraphFilter() {
 
 	$.ajaxQ.abortAll();
 	$.get(new_href+'&header=false')
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#main').hide();
@@ -1862,8 +1871,8 @@ function applyGraphFilter() {
 
 			pushState(myTitle, myHref);
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -1880,7 +1889,7 @@ function pushState(myTitle, myHref) {
 	if (myHref.indexOf('nostate') < 0) {
 		if (statePushed == false) {
 			var myObject = { myTitle: myHref };
-			if (typeof window.history.pushState !== 'undefined') {
+			if (typeof window.history.pushState != 'undefined') {
 				window.history.pushState(myObject, myTitle, cleanHeader(myHref));
 			}
 		}
@@ -1920,7 +1929,7 @@ function applyGraphTimespan() {
 	$.get(new_href+'?action='+pageAction+'&header=false'+
 		'&predefined_timespan='+$('#predefined_timespan').val()+
 		'&predefined_timeshift='+$('#predefined_timeshift').val())
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#main').empty().hide();
@@ -1928,8 +1937,8 @@ function applyGraphTimespan() {
 			$('#main').html(data);
 			applySkin();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2032,14 +2041,14 @@ function clearGraphTimespanFilter() {
 function removeSpikesStdDev(local_graph_id) {
 	strURL = 'spikekill.php?method=stddev&local_graph_id='+local_graph_id;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
 			$('#spikeresults').remove();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2047,14 +2056,14 @@ function removeSpikesStdDev(local_graph_id) {
 function removeSpikesVariance(local_graph_id) {
 	strURL = "spikekill.php?method=variance&local_graph_id="+local_graph_id;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
 			$('#spikeresults').remove();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2062,14 +2071,14 @@ function removeSpikesVariance(local_graph_id) {
 function removeSpikesInRange(local_graph_id) {
 	strURL = 'spikekill.php?method=fill&avgnan=last&local_graph_id='+local_graph_id+'&outlier-start='+graph_start+'&outlier-end='+graph_end;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
 			$('#spikeresults').remove();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2077,14 +2086,14 @@ function removeSpikesInRange(local_graph_id) {
 function removeRangeFill(local_graph_id) {
 	strURL = 'spikekill.php?method=float&avgnan=last&local_graph_id='+local_graph_id+'&outlier-start='+graph_start+'&outlier-end='+graph_end;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
 			$('#spikeresults').remove();
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2092,7 +2101,7 @@ function removeRangeFill(local_graph_id) {
 function dryRunStdDev(local_graph_id) {
 	strURL = "spikekill.php?method=stddev&dryrun=true&local_graph_id="+local_graph_id;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#spikeresults').remove();
@@ -2100,8 +2109,8 @@ function dryRunStdDev(local_graph_id) {
 			$('#spikeresults').html(data.results);
 			$('#spikeresults').dialog({ width:1100, maxHeight: 600 });
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2109,7 +2118,7 @@ function dryRunStdDev(local_graph_id) {
 function dryRunVariance(local_graph_id) {
 	strURL = "spikekill.php?method=variance&dryrun=true&local_graph_id="+local_graph_id;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			$('#spikeresults').remove();
@@ -2117,8 +2126,8 @@ function dryRunVariance(local_graph_id) {
 			$('#spikeresults').html(data.results);
 			$('#spikeresults').dialog({ width:1100, maxHeight: 600 });
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2126,7 +2135,7 @@ function dryRunVariance(local_graph_id) {
 function dryRunSpikesInRange(local_graph_id) {
 	strURL = 'spikekill.php?method=fill&avgnan=last&dryrun=true&local_graph_id='+local_graph_id+'&outlier-start='+graph_start+'&outlier-end='+graph_end;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
@@ -2135,8 +2144,8 @@ function dryRunSpikesInRange(local_graph_id) {
 			$('#spikeresults').html(data.results);
 			$('#spikeresults').dialog({ width:1100, maxHeight: 600 });
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2144,7 +2153,7 @@ function dryRunSpikesInRange(local_graph_id) {
 function dryRunRangeFill(local_graph_id) {
 	strURL = 'spikekill.php?method=float&avgnan=last&dryrun=true&local_graph_id='+local_graph_id+'&outlier-start='+graph_start+'&outlier-end='+graph_end;
 	$.getJSON(strURL)
-		.success(function(data) {
+		.done(function(data) {
 			checkForLogout(data);
 
 			redrawGraph(local_graph_id);
@@ -2153,8 +2162,8 @@ function dryRunRangeFill(local_graph_id) {
 			$('#spikeresults').html(data.results);
 			$('#spikeresults').dialog({ width:1100, maxHeight: 600 });
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2185,40 +2194,46 @@ function redrawGraph(graph_id) {
 		'&graph_height='+graph_height+
 		'&graph_width='+graph_width+
 		(isThumb ? '&graph_nolegend=true':''))
-		.success(function(data) {
-			if (myWidth < data.image_width) {
-				ratio=myWidth/data.image_width;
-				data.image_width  = parseInt(data.image_width  * ratio);
-				data.image_height = parseInt(data.image_height * ratio);
-				data.graph_width  = parseInt(data.graph_width  * ratio);
-				data.graph_height = parseInt(data.graph_height * ratio);
-				data.graph_top    = parseInt(data.graph_top  * ratio);
-				data.graph_left   = parseInt(data.graph_left * ratio);
-			}
+		.done(function(data) {
+			if (typeof data.status == 'undefined') {
+				if (myWidth < data.image_width) {
+					ratio=myWidth/data.image_width;
+					data.image_width  = parseInt(data.image_width  * ratio);
+					data.image_height = parseInt(data.image_height * ratio);
+					data.graph_width  = parseInt(data.graph_width  * ratio);
+					data.graph_height = parseInt(data.graph_height * ratio);
+					data.graph_top    = parseInt(data.graph_top  * ratio);
+					data.graph_left   = parseInt(data.graph_left * ratio);
+				}
 
-			$('#wrapper_'+data.local_graph_id).html(
-				"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
-				" src='data:image/"+data.type+";base64,"+data.image+"'"+
-				" graph_start='"+data.graph_start+"'"+
-				" graph_end='"+data.graph_end+"'"+
-				" graph_left='"+data.graph_left+"'"+
-				" graph_top='"+data.graph_top+"'"+
-				" graph_width='"+data.graph_width+"'"+
-				" graph_height='"+data.graph_height+"'"+
-				" width='"+data.image_width+"'"+
-				" height='"+data.image_height+"'"+
-				" image_width='"+data.image_width+"'"+
-				" image_height='"+data.image_height+"'"+
-				" canvas_top='"+data.graph_top+"'"+
-				" canvas_left='"+data.graph_left+"'"+
-				" canvas_width='"+data.graph_width+"'"+
-				" canvas_height='"+data.graph_height+"'"+
-				" value_min='"+data.value_min+"'"+
-				" value_max='"+data.value_max+"'>"
-			);
+				$('#wrapper_'+data.local_graph_id).html(
+					"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
+					" src='data:image/"+data.type+";base64,"+data.image+"'"+
+					" rra_id='"+data.rra_id+"'"+
+					" graph_id='"+data.local_graph_id+"'"+
+					" graph_start='"+data.graph_start+"'"+
+					" graph_end='"+data.graph_end+"'"+
+					" graph_left='"+data.graph_left+"'"+
+					" graph_top='"+data.graph_top+"'"+
+					" graph_width='"+data.graph_width+"'"+
+					" graph_height='"+data.graph_height+"'"+
+					" width='"+data.image_width+"'"+
+					" height='"+data.image_height+"'"+
+					" image_width='"+data.image_width+"'"+
+					" image_height='"+data.image_height+"'"+
+					" canvas_top='"+data.graph_top+"'"+
+					" canvas_left='"+data.graph_left+"'"+
+					" canvas_width='"+data.graph_width+"'"+
+					" canvas_height='"+data.graph_height+"'"+
+					" value_min='"+data.value_min+"'"+
+					" value_max='"+data.value_max+"'>"
+				);
+			} else {
+				getPresentHTTPError(data);
+			}
 		})
-		.error(function(data) {
-			getPresentHTTPError(data.responseText);
+		.fail(function(data) {
+			getPresentHTTPError(data);
 		}
 	);
 }
@@ -2231,7 +2246,7 @@ function initializeGraphs() {
 		graph_id=$(this).attr('id').replace('graph_','').replace('_mrtg','');
 		$.ajaxQ.abortAll();
 		$.get(urlPath+'graph.php?local_graph_id='+graph_id+'&header=false')
-			.success(function(data) {
+			.done(function(data) {
 				checkForLogout(data);
 
 				$('#main').empty().hide();
@@ -2242,8 +2257,8 @@ function initializeGraphs() {
 				applySkin();
 				clearTimeout(myRefresh);
 			})
-			.error(function(data) {
-				getPresentHTTPError(data.responseText);
+			.fail(function(data) {
+				getPresentHTTPError(data);
 			}
 		);
 	});
@@ -2271,18 +2286,27 @@ function initializeGraphs() {
 	myWidth = (mainWidth-(30*myColumns))/myColumns;
 
 	$('.graphWrapper').each(function() {
-		graph_id=$(this).attr('id').replace('wrapper_','');
+		graph_id=$(this).attr('graph_id');
+		if (!(graph_id > 0)) {
+			graph_id=$(this).attr('id').replace('wrapper_','');
+		}
+
+		rra_id=$(this).attr('rra_id');
+		if (!(rra_id > 0)) {
+			rra_id=0;
+		}
+
 		graph_height=$(this).attr('graph_height');
 		graph_width=$(this).attr('graph_width');
 
-		$.getJSON(urlPath+'graph_json.php?rra_id=0'+
+		$.getJSON(urlPath+'graph_json.php?rra_id='+rra_id+
 			'&local_graph_id='+graph_id+
 			'&graph_start='+graph_start+
 			'&graph_end='+graph_end+
 			'&graph_height='+graph_height+
 			'&graph_width='+graph_width+
 			(isThumb ? '&graph_nolegend=true':''))
-			.success(function(data) {
+			.done(function(data) {
 				if (myWidth < data.image_width) {
 					ratio=myWidth/data.image_width;
 					data.image_width  = parseInt(data.image_width  * ratio);
@@ -2292,10 +2316,15 @@ function initializeGraphs() {
 					data.graph_top    = parseInt(data.graph_top  * ratio);
 					data.graph_left   = parseInt(data.graph_left * ratio);
 				}
+				var wrapper_id = '#wrapper_'+data.local_graph_id;
+				if (rra_id > 0) {
+					wrapper_id += '[rra_id=\'' + data.rra_id + '\']';
+				}
 
-				$('#wrapper_'+data.local_graph_id).html(
+				$(wrapper_id).html(
 					"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
 					" src='data:image/"+data.type+";base64,"+data.image+"'"+
+					" rra_id='"+data.rra_id+"'"+
 					" graph_start='"+data.graph_start+"'"+
 					" graph_end='"+data.graph_end+"'"+
 					" graph_left='"+data.graph_left+"'"+
@@ -2314,7 +2343,12 @@ function initializeGraphs() {
 					" value_max='"+data.value_max+"'>"
 				);
 
-				$("#graph_"+data.local_graph_id).zoom({
+				var graph_id = '#graph_'+data.local_graph_id;
+				if (rra_id > 0) {
+					graph_id += '[rra_id=\'' + data.rra_id + '\']';
+				}
+
+				$(graph_id).zoom({
 					inputfieldStartTime : 'date1',
 					inputfieldEndTime : 'date2',
 					serverTimeOffset : timeOffset
@@ -2322,8 +2356,8 @@ function initializeGraphs() {
 
 				realtimeArray[data.local_graph_id] = false;
 			})
-			.error(function(data) {
-				getPresentHTTPError(data.responseText);
+			.fail(function(data) {
+				getPresentHTTPError(data);
 			}
 		);
 	});
@@ -2342,7 +2376,7 @@ function initializeGraphs() {
 		graph_id=$(this).attr('id').replace('graph_','').replace('_util','');
 		$.ajaxQ.abortAll();
 		$.get(urlPath+'graph.php?action=zoom&header=false&local_graph_id='+graph_id+'&rra_id=0&graph_start='+getTimestampFromDate($('#date1').val())+'&graph_end='+getTimestampFromDate($('#date2').val()))
-			.success(function(data) {
+			.done(function(data) {
 				checkForLogout(data);
 
 				$('#main').empty().hide();
@@ -2352,8 +2386,8 @@ function initializeGraphs() {
 				applySkin();
 				clearTimeout(myRefresh);
 			})
-			.error(function(data) {
-				getPresentHTTPError(data.responseText);
+			.fail(function(data) {
+				getPresentHTTPError(data);
 			}
 		);
 	});
