@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,6 +22,21 @@
  +-------------------------------------------------------------------------+
 */
 
+function clog_get_datasource_titles($local_data_ids) {
+	if (!is_array($local_data_ids)) {
+		$local_data_ids = array($local_data_ids);
+	}
+
+	$titles = array();
+	foreach ($local_data_ids as $local_data_id) {
+		if (!array_key_exists($local_data_id, $titles)) {
+			$titles[$local_data_id] = get_data_source_title($local_data_id);
+		}
+	}
+	
+	return $titles;
+}
+
 function clog_get_graphs_from_datasource($local_data_id) {
 	return array_rekey(db_fetch_assoc_prepared('SELECT DISTINCT
 		gtg.local_graph_id AS id,
@@ -39,15 +54,24 @@ function clog_get_graphs_from_datasource($local_data_id) {
 function clog_purge_logfile() {
 	global $config;
 
-	$logfile   = read_config_option('path_cactilog');
-
+	$logfile = read_config_option('path_cactilog');
+	$logbase = basename($logfile);
 	if ($logfile == '') {
 		$logfile = $config['base_path'] . '/log/cacti.log';
 	}
 
+	if (get_nfilter_request_var('filename') != '') {
+		if (strpos(get_nfilter_request_var('filename'), $logbase) === false) {
+			raise_message('clog_invalid');
+			header('Location: ' . get_current_page() . '?filename=' . $logbase);
+			exit(0);
+		}
+	}
+
 	$purgefile = dirname($logfile) . '/' . get_nfilter_request_var('filename');
 	if (strstr($purgefile, $logfile) === false) {
 		raise_message('clog_invalid');
+		header('Location: ' . get_current_page() . '?header=false');
 		exit(0);
 	}
 
@@ -76,8 +100,11 @@ function clog_purge_logfile() {
 function clog_view_logfile() {
 	global $config;
 
+	$exclude_reported = false;
+
 	$clogAdmin = clog_admin();
 	$logfile   = read_config_option('path_cactilog');
+	$logbase   = basename($logfile);
 
 	if (isset_request_var('filename')) {
 		$requestedFile = dirname($logfile) . '/' . basename(get_nfilter_request_var('filename'));
@@ -88,6 +115,14 @@ function clog_view_logfile() {
 		$logfile = $config['base_path'] . '/log/cacti.log';
 	}
 
+	if (get_nfilter_request_var('filename') != '') {
+		if (strpos(get_nfilter_request_var('filename'), $logbase) === false) {
+			raise_message('clog_invalid');
+			header('Location: ' . get_current_page() . '?filename=' . $logbase);
+			exit(0);
+		}
+	}
+
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'page' => array(
@@ -208,6 +243,7 @@ function clog_view_logfile() {
 		}
 	} else {
 		$ad_filter = __(' - Admin View');
+		$exclude_regex = '';
 	}
 
 	if (get_request_var('message_type') > 0) {
@@ -225,7 +261,7 @@ function clog_view_logfile() {
 
 	$nav = html_nav_bar($base_url, MAX_DISPLAY_PAGES, $page_nr, $number_of_lines, $total_rows, 13, __('Entries'), 'page', 'main');
 
-	echo $nav;
+	print $nav;
 
 	html_start_box($start_string, '100%', '', '3', 'center', '');
 
@@ -237,66 +273,22 @@ function clog_view_logfile() {
 		$hostDescriptions[$host['id']] = html_escape($host['description']);
 	}
 
+	$regex_array = clog_get_regex_array();
 	foreach ($logcontents as $item) {
-		$host_start = strpos($item, 'Device[');
-		$ds_start   = strpos($item, 'DS[');
+		$new_item = html_escape($item);
 
-		if (!$host_start && !$ds_start) {
-			$new_item = html_escape($item);
-		} else {
-			$new_item = '';
-			if ($host_start) {
-				$host_end    = strpos($item, ']', $host_start);
-				$host_id     = substr($item, $host_start + 7, $host_end - ($host_start + 7));
-				$new_item   .= substr($item, 0, $host_start) . " Device[<a href='" . html_escape($config['url_path'] . 'host.php?action=edit&id=' . $host_id) . "'>" . (isset($hostDescriptions[$host_id]) ? $hostDescriptions[$host_id]:'') . '</a>]';
-				$item        = substr($item, $host_end + 1);
-			}
-
-			$ds_start   = strpos($item, 'DS[');
-			if ($ds_start) {
-				$ds_end    = strpos($item, ']', $ds_start);
-				$ds_id     = substr($item, $ds_start + 3, $ds_end - ($ds_start + 3));
-				$ds_ids    = explode(', ', $ds_id);
-				if (sizeof($ds_ids)) {
-					$graph_add = $config['url_path'] . 'graph_view.php?page=1&style=selective&action=preview&graph_add=';
-
-					$new_item  .= " Graphs[<a href='";
-					$titles = '';
-					$i = 0;
-					foreach($ds_ids as $ds_id) {
-						$graph_ids = clog_get_graphs_from_datasource($ds_id);
-
-						if (sizeof($graph_ids)) {
-							foreach($graph_ids as $key => $title) {
-								$graph_add .= ($i > 0 ? '%2C' : '') . $key;
-								if ($titles != '') {
-									$titles .= ", '" . html_escape($title) . "'";
-								} else {
-									$titles .= "'"  . html_escape($title) . "'";
-								}
-								$i++;
-							}
-						}
-					}
-
-					$new_item .= html_escape($graph_add) . "' title='" . __esc('View Graphs') . "'>" . $titles . '</a>]';
-
-					$new_item .= ' DS[';
-					$i = 0;
-					foreach($ds_ids as $ds_id) {
-						$new_item .= ($i == 0 ? '':', ') . "<a href='" . html_escape($config['url_path'] . 'data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . $ds_id . '</a>';
-						$i++;
-					}
-					$new_item .= ']';
-				}
-			}else{
-				$new_item .= html_escape($item);
-			}
-		}
+		$new_item = preg_replace_callback($regex_array['complete'],'clog_regex_parser',$new_item);
 
 		/* respect the exclusion filter */
-		if (!$clogAdmin && @preg_match($exclude_regex, $new_item)) {
-			continue;
+		if ($exclude_regex != '' && !$clogAdmin) {
+			if (validate_is_regex($exclude_regex)) {
+				if (preg_match($exclude_regex, $new_item)) {
+					continue;
+				}
+			} elseif (!$exclude_reported) {
+				cacti_log('Cacti Log Exclude Regex "' . $exclude_regex . '" is Invalid.  Update your Exclude Regex to be valid!');
+				$exclude_reported = true;
+			}
 		}
 
 		/* get the background color */
@@ -331,7 +323,7 @@ function clog_view_logfile() {
 	html_end_box();
 
 	if ($total_rows) {
-		echo $nav;
+		print $nav;
 	}
 
 	bottom_footer();
@@ -349,8 +341,11 @@ function filter($clogAdmin) {
 						<?php print __('File');?>
 					</td>
 					<td>
+						<select id='filename'>
 						<?php
 						$configLogPath = read_config_option('path_cactilog');
+						$configLogBase = basename($configLogPath);
+						$selectedFile  = basename(get_nfilter_request_var('filename'));
 
 						if ($configLogPath == '') {
 							$logPath = $config['base_path'] . '/log/';
@@ -361,16 +356,11 @@ function filter($clogAdmin) {
 						if (is_readable($logPath)) {
 							$files = scandir($logPath);
 						} else {
-							$files = false;
+							$files = array('cacti.log');
 						}
 
-						if ($files === false) {
-							echo '<select id="filename" name="filename">
-									<option value="cacti.log">cacti.log</option>';
-						} else {
-							echo '<select id="filename" name="filename">';
-							$selectedFile = basename(get_nfilter_request_var('filename'));
-
+						if (sizeof($files)) {
+							$logFileArray = array();
 							foreach ($files as $logFile) {
 								if (in_array($logFile, array('.', '..', '.htaccess'))) {
 									continue;
@@ -381,10 +371,26 @@ function filter($clogAdmin) {
 									continue;
 								}
 
+								if (strpos($logFile, $configLogBase) === false) {
+									continue;
+								}
+
+								if (strcmp($logFile, 'cacti.log') == 0) {
+									continue;
+								}
+								$logFileArray[] = $logFile;
+							}
+
+							arsort($logFileArray);
+							array_unshift($logFileArray,'cacti.log');
+
+							foreach ($logFileArray as $logFile) {
 								print "<option value='" . $logFile . "'";
+
 								if ($selectedFile == $logFile) {
 									print ' selected';
 								}
+
 								print '>' . $logFile . "</option>\n";
 							}
 						}
@@ -521,7 +527,8 @@ function filter($clogAdmin) {
 		function refreshFilter() {
 			refreshMSeconds=$('#refresh').val()*1000;
 
-			strURL = basename(location.pathname) + '?rfilter='+ $('#rfilter').val()+
+			strURL = basename(location.pathname)+
+				'?rfilter=' + base64_encode($('#rfilter').val())+
 				'&reverse='+$('#reverse').val()+
 				'&refresh='+$('#refresh').val()+
 				'&message_type='+$('#message_type').val()+
@@ -529,6 +536,7 @@ function filter($clogAdmin) {
 				'&filename='+$('#filename').val()+
 				'&header=false';
 
+			console.log(strURL);
 			loadPageNoHeader(strURL);
 		}
 		</script>
@@ -536,3 +544,203 @@ function filter($clogAdmin) {
 	</tr>
 	<?php
 }
+
+function clog_get_regex_array() {
+	static $regex_array = array();
+
+	if (!sizeof($regex_array)) {
+		$regex_array = array(
+			1 => array('name' => 'DS',     'regex' => '( DS\[)([, \d]+)(\])',      'func' => 'clog_regex_datasource'),
+			2 => array('name' => 'DQ',     'regex' => '( DQ\[)([, \d]+)(\])',      'func' => 'clog_regex_dataquery'),
+			3 => array('name' => 'Device', 'regex' => '( Device\[)([, \d]+)(\])',  'func' => 'clog_regex_device'),
+			4 => array('name' => 'Poller', 'regex' => '( Poller\[)([, \d]+)(\])',  'func' => 'clog_regex_poller'),
+			5 => array('name' => 'RRA',    'regex' => "([_\/])(\d+)(\.rrd&#039;)", 'func' => 'clog_regex_rra')
+		);
+
+		$regex_array = api_plugin_hook_function('clog_regex_array',$regex_array);
+		$regex_complete = '';
+		foreach ($regex_array as $regex_key => $regex_setting) {
+			$regex_complete .= (strlen($regex_complete)?')|(':'').$regex_setting['regex'];
+		}
+		$regex_complete = '~('.$regex_complete.')~';
+		$regex_array['complete'] = $regex_complete;
+	}
+
+	return $regex_array;
+}
+
+function clog_regex_parser($matches) {
+	$result = $matches[0];
+	$match = $matches[0];
+
+	$key_match = -1;
+	for ($index = 1; $index < sizeof($matches); $index++) {
+		if ($match == $matches[$index]) {
+			$key_match = $index;
+		}
+	}
+
+	if ($key_match != -1) {
+		$key_setting = ($key_match - 1) / 4 + 1;
+		$regex_array = clog_get_regex_array();
+		if (sizeof($regex_array)) {
+			if (array_key_exists($key_setting, $regex_array)) {
+				$regex_setting = $regex_array[$key_setting];
+
+				$rekey_array = array();
+				for ($j = 0; $j < 4; $j++) {
+					$rekey_array[$j] = $matches[$key_match + $j];
+				}
+
+				$result=call_user_func_array($regex_setting['func'],array($rekey_array));
+			}
+		}
+	}
+
+	return $result;
+}
+
+function clog_regex_device($matches) {
+	global $config;
+
+	$result = $matches[0];
+
+	$dev_ids = explode(',',str_replace(" ","",$matches[2]));
+	if (sizeof($dev_ids)) {
+		$hosts = db_fetch_assoc_prepared('SELECT id, description
+			FROM host
+			WHERE id in (?)',
+			array(implode(',',$dev_ids)));
+		
+		$hostDescriptions = array();
+		foreach ($hosts as $host) {
+			$hostDescriptions[$host['id']] = html_escape($host['description']);
+		}
+
+		foreach ($dev_ids as $host_id) {
+			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'host.php?action=edit&id=' . $host_id) . '\'>' . (isset($hostDescriptions[$host_id]) ? $hostDescriptions[$host_id]:$host_id) . '</a>' . $matches[3];
+		}
+	}
+
+	return $result;
+}
+
+function clog_regex_datasource($matches) {
+	global $config;
+
+	$result = $matches[0];
+
+	$ds_ids = explode(',',str_replace(" ","",$matches[2]));
+	if (sizeof($ds_ids)) {
+		$result = '';
+		$graph_add = $config['url_path'] . 'graph_view.php?page=1&style=selective&action=preview&graph_add=';
+
+		$title = '';
+		$i     = 0;
+
+		foreach($ds_ids as $ds_id) {
+			$graph_ids = clog_get_graphs_from_datasource($ds_id);
+
+			if (sizeof($graph_ids)) {
+				$result .= " Graphs[<a href='";
+
+				foreach($graph_ids as $key => $title) {
+					$graph_add .= ($i > 0 ? '%2C' : '') . $key;
+					$title     .= ($title != '' ? ', ':'') . html_escape($title);
+
+					$i++;
+				}
+
+				$result .= html_escape($graph_add) . "' title='" . __esc('View Graphs') . "'>" . $title . '</a>]';
+			}
+		}
+
+		$result .= $matches[1];
+		$i       = 0;
+
+		$ds_titles = clog_get_datasource_titles($ds_ids);
+		foreach($ds_ids as $ds_id) {
+			$ds_title = $ds_id;
+			if (array_key_exists($ds_id, $ds_titles)) {
+				$ds_title = $ds_titles[$ds_id];
+			}
+			$result .= ($i == 0 ? '':', ') . "<a href='" . html_escape($config['url_path'] . 'data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . $ds_title . '</a>';
+
+			$i++;
+		}
+
+		$result .= $matches[3];
+	}
+
+	return $result;
+}
+
+function clog_regex_poller($matches) {
+	global $config;
+
+	$result = $matches[0];
+
+	$poller_ids = explode(',',str_replace(" ","",$matches[2]));
+	if (sizeof($poller_ids)) {
+		$result = '';
+		$pollers = db_fetch_assoc_prepared('SELECT id, name
+			FROM poller
+			WHERE id in (?)',
+			array(implode(',',$poller_ids)));
+		
+		$pollerDescriptions = array();
+		foreach ($pollers as $poller) {
+			$pollerDescriptions[$poller['id']] = html_escape($poller['name']);
+		}
+
+		foreach ($poller_ids as $poller_id) {
+			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'pollers.php?action=edit&id=' . $poller_id) . '\'>' . (isset($pollerDescriptions[$poller_id]) ? $pollerDescriptions[$poller_id]:$poller_id) . '</a>' . $matches[3];
+		}
+	}
+
+	return $result;
+}
+
+function clog_regex_dataquery($matches) {
+	global $config;
+
+	$result = $matches[0];
+
+	$query_ids = explode(',',str_replace(" ","",$matches[2]));
+	if (sizeof($query_ids)) {
+		$result = '';
+		$querys = db_fetch_assoc_prepared('SELECT id, name
+			FROM snmp_query
+			WHERE id in (?)',
+			array(implode(',',$query_ids)));
+
+		$queryDescriptions = array();
+		foreach ($querys as $query) {
+			$queryDescriptions[$query['id']] = html_escape($query['name']);
+		}
+
+		foreach ($query_ids as $query_id) {
+			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'data_query.php?action=edit&id=' . $query_id) . '\'>' . (isset($queryDescriptions[$query_id]) ? $queryDescriptions[$query_id]:$query_id) . '</a>' . $matches[3];
+		}
+	}
+
+	return $result;
+}
+
+function clog_regex_rra($matches) {
+	global $config;
+
+	$result = $matches[0];
+
+	$local_data_ids = $matches[2];
+	if (strlen($local_data_ids)) {
+		$datasource_array = array( 0 => '', 1 => 'DS[', 2 => $local_data_ids, 3 => ']');
+		$datasource_result = clog_regex_datasource($datasource_array);
+		if (strlen($datasource_result)) {
+			$result .= ' '. $datasource_result;
+		}
+	}
+
+	return $result;
+}
+
